Python: module TileStache.Goodies.Providers.UtfGridCompositeOverlap

TileStache.Goodies.Providers.UtfGridCompositeOverlap | index

Modules
`` |  |
TileStache | json |  |

Classes
`` |  | Provider SaveableResponse
class Provider
`` |  | Methods defined here: __init__(self, layer, stack, layer_id=None, wrapper=None) addLayer(self, layerDef, coord) decodeId(self, id) encodeId(self, id) getTypeByExtension(self, extension) `Get mime-type and format by file extension. This only accepts "json".` renderTile(self, width, height, srs, coord) writeResult(self)
class SaveableResponse
`` | `Wrapper class for JSON response that makes it behave like a PIL.Image object. TileStache.getTile() expects to be able to save one of these to a buffer.`
| Methods defined here: __init__(self, content) save(self, out, format)